@@ -390,9 +390,11 @@ get_place_type_from_attributes (GHashTable *ht)
                 place_type =  GEOCODE_PLACE_TYPE_DRAINAGE;
         } else if (g_strcmp0 (category, "boundary") == 0) {
                 if (g_strcmp0 (type, "administrative") == 0) {
+                        const char *place_rank;
                         int rank;
 
-                        rank = atoi (g_hash_table_lookup (ht, "place_rank"));
+                        place_rank = g_hash_table_lookup (ht, "place_rank");
+                        rank = place_rank ? atoi (place_rank) : 0;
                         if (rank < 2)
                                 place_type =  GEOCODE_PLACE_TYPE_UNKNOWN;
 
@@ -1063,21 +1065,24 @@ _geocode_read_nominatim_attributes (JsonReader *reader,
 	}
 
 	for (i = 0; members[i] != NULL; i++) {
-		const char *value = NULL;
+		char *value = NULL;
 
 		json_reader_read_member (reader, members[i]);
 
 		if (json_reader_is_value (reader)) {
 			JsonNode *node = json_reader_get_value (reader);
 			if (json_node_get_value_type (node) == G_TYPE_STRING) {
-				value = json_node_get_string (node);
+				value = g_strdup (json_node_get_string (node));
 				if (value && *value == '\0')
-					value = NULL;
+					g_clear_pointer (&value, g_free);
+			} else if (json_node_get_value_type (node) == G_TYPE_INT64) {
+				gint64 int_value = json_node_get_int (node);
+				value = g_strdup_printf ("%"G_GINT64_FORMAT, int_value);
 			}
 		}
 
 		if (value != NULL) {
-			g_hash_table_insert (ht, g_strdup (members[i]), g_strdup (value));
+			g_hash_table_insert (ht, g_strdup (members[i]), value);
 
 			if (i == 0 && is_address) {
 				if (g_strcmp0 (members[i], "house_number") != 0)
