@@ -628,6 +628,19 @@ test_distance (void)
 	g_assert_cmpfloat (geocode_location_get_distance_from (loca, locb) - 0.549311, <, 0.000001);
 }
 
+static void
+test_zero_distance (void)
+{
+	g_autoptr (GeocodeLocation) loca = NULL, locb = NULL;
+
+	/* 1600 Pennsylvania Ave NW, Washington, DC */
+	loca = geocode_location_new (38.898556, -77.037852, GEOCODE_LOCATION_ACCURACY_UNKNOWN);
+	/* 1600 Pennsylvania Ave NW, Washington, DC */
+	locb = geocode_location_new (38.898556, -77.037852, GEOCODE_LOCATION_ACCURACY_UNKNOWN);
+
+	g_assert_cmpfloat (geocode_location_get_distance_from (loca, locb), ==, 0.0);
+}
+
 static void
 test_locale_format (void)
 {
@@ -768,12 +781,15 @@ test_resolve_json (void)
 	guint i;
 	struct {
 		const char *fname;
+		guint num_results;
 		const char *error;
 		const char *prop;
 		const char *value;
 	} tests[] = {
-		{ "nominatim-area.json", NULL, "area", "Guildford Park" },
-		{ "nominatim-no-results.json", "No matches found for request", NULL, NULL },
+		{ "nominatim-area.json", 1, NULL, "area", "Guildford Park" },
+		{ "nominatim-no-results.json", 1, "No matches found for request", NULL, NULL },
+		{ "nominatim-data-type-change.json", 12, NULL, "osm_id", "335673748" },
+		{ "nominatim-place_rank.json", 10, NULL, "osm_id", "2555133" },
 	};
 
 	for (i = 0; i < G_N_ELEMENTS (tests); i++) {
@@ -798,7 +814,7 @@ test_resolve_json (void)
 			g_assert_cmpstr (error->message, ==, tests[i].error);
 		} else {
                         g_assert (list != NULL);
-                        g_assert_cmpint (g_list_length (list), ==, 1);
+                        g_assert_cmpint (g_list_length (list), ==, tests[i].num_results);
 		}
 
 		if (list == NULL) {
@@ -914,6 +930,7 @@ int main (int argc, char **argv)
 		g_test_add_func ("/geocode/search", test_search);
 		g_test_add_func ("/geocode/search_lat_long", test_search_lat_long);
 		g_test_add_func ("/geocode/distance", test_distance);
+		g_test_add_func ("/geocode/zero_distance", test_zero_distance);
 		g_test_add_func ("/geocode/osm_type", test_osm_type);
 		return g_test_run ();
 	}
